#[repr(i32)]pub enum Capability {
CapUnused = 0,
CapPacketTrailer = 1,
}Expand description
Optional capabilities advertised by the client at connect time. The SFU uses these flags to decide whether to enable features that require client-side support (e.g. passing RTP packet trailers through to the subscriber instead of stripping them).
Variants
Implementations
Sourceimpl Capability
impl Capability
Sourceimpl Capability
impl Capability
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.