#[repr(i32)]pub enum CompressionType {
None = 0,
DeflateRaw = 1,
}Expand description
The compression type of the whole data stream
This will only get populated when send to participants with a client protocol >= 2 which advertise a client capability of CAP_COMPRESSION_DEFLATE_RAW
Variants
Implementations
Sourceimpl CompressionType
impl CompressionType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.