#[repr(i32)]pub enum AnalyticsEventType {
Show 45 variants
RoomCreated = 0,
RoomEnded = 1,
ParticipantJoined = 2,
ParticipantLeft = 3,
ParticipantConnectionAborted = 45,
TrackPublished = 4,
TrackPublishRequested = 20,
TrackUnpublished = 5,
TrackSubscribed = 6,
TrackSubscribeRequested = 21,
TrackSubscribeFailed = 25,
TrackUnsubscribed = 7,
TrackPublishedUpdate = 10,
TrackMuted = 23,
TrackUnmuted = 24,
TrackPublishStats = 26,
TrackSubscribeStats = 27,
ParticipantActive = 11,
ParticipantResumed = 22,
EgressStarted = 12,
EgressEnded = 13,
EgressUpdated = 28,
TrackMaxSubscribedVideoQuality = 14,
Reconnected = 15,
IngressCreated = 18,
IngressDeleted = 19,
IngressStarted = 16,
IngressEnded = 17,
IngressUpdated = 29,
SipInboundTrunkCreated = 30,
SipInboundTrunkDeleted = 31,
SipOutboundTrunkCreated = 32,
SipOutboundTrunkDeleted = 33,
SipDispatchRuleCreated = 34,
SipDispatchRuleDeleted = 35,
SipParticipantCreated = 36,
SipCallIncoming = 37,
SipCallStarted = 38,
SipCallEnded = 39,
SipTransferRequested = 43,
SipTransferComplete = 44,
SipCallUpdate = 46,
Report = 40,
ApiCall = 41,
Webhook = 42,
}Variants
RoomCreated = 0
RoomEnded = 1
ParticipantJoined = 2
ParticipantLeft = 3
ParticipantConnectionAborted = 45
TrackPublished = 4
TrackPublishRequested = 20
TrackUnpublished = 5
TrackSubscribed = 6
TrackSubscribeRequested = 21
TrackSubscribeFailed = 25
TrackUnsubscribed = 7
TrackPublishedUpdate = 10
TrackMuted = 23
TrackUnmuted = 24
TrackPublishStats = 26
TrackSubscribeStats = 27
ParticipantActive = 11
ParticipantResumed = 22
EgressStarted = 12
EgressEnded = 13
EgressUpdated = 28
TrackMaxSubscribedVideoQuality = 14
Reconnected = 15
IngressCreated = 18
IngressDeleted = 19
IngressStarted = 16
IngressEnded = 17
IngressUpdated = 29
SipInboundTrunkCreated = 30
SipInboundTrunkDeleted = 31
SipOutboundTrunkCreated = 32
SipOutboundTrunkDeleted = 33
SipDispatchRuleCreated = 34
SipDispatchRuleDeleted = 35
SipParticipantCreated = 36
SipCallIncoming = 37
SipCallStarted = 38
SipCallEnded = 39
SipTransferRequested = 43
SipTransferComplete = 44
SipCallUpdate = 46
Report = 40
ApiCall = 41
Webhook = 42
Implementations
Sourceimpl AnalyticsEventType
impl AnalyticsEventType
Sourcepub fn from_i32(value: i32) -> Option<AnalyticsEventType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<AnalyticsEventType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a AnalyticsEventType, or None if value is not a valid variant.
Sourceimpl AnalyticsEventType
impl AnalyticsEventType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.