#[repr(i32)]pub enum BackupCodecPolicy {
PreferRegression = 0,
Simulcast = 1,
Regression = 2,
}Expand description
Policy for publisher to handle subscribers that are unable to support the primary codec of a track
Variants
PreferRegression = 0
default behavior, the track prefer to regress to backup codec and all subscribers will receive the backup codec, the sfu will try to regress codec if possible but not assured.
Simulcast = 1
encoding/send the primary and backup codec simultaneously
Regression = 2
force the track to regress to backup codec, this option can be used in video conference or the publisher has limited bandwidth/encoding power
Implementations
Sourceimpl BackupCodecPolicy
impl BackupCodecPolicy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.