#[repr(i32)]pub enum DisconnectReason {
Show 17 variants
UnknownReason = 0,
ClientInitiated = 1,
DuplicateIdentity = 2,
ServerShutdown = 3,
ParticipantRemoved = 4,
RoomDeleted = 5,
StateMismatch = 6,
JoinFailure = 7,
Migration = 8,
SignalClose = 9,
RoomClosed = 10,
UserUnavailable = 11,
UserRejected = 12,
SipTrunkFailure = 13,
ConnectionTimeout = 14,
MediaFailure = 15,
AgentError = 16,
}Variants
UnknownReason = 0
ClientInitiated = 1
the client initiated the disconnect
DuplicateIdentity = 2
another participant with the same identity has joined the room
ServerShutdown = 3
the server instance is shutting down
ParticipantRemoved = 4
RoomService.RemoveParticipant was called
RoomDeleted = 5
RoomService.DeleteRoom was called
StateMismatch = 6
the client is attempting to resume a session, but server is not aware of it
JoinFailure = 7
client was unable to connect fully
Migration = 8
Cloud-only, the server requested Participant to migrate the connection elsewhere
SignalClose = 9
the signal websocket was closed unexpectedly
RoomClosed = 10
the room was closed, due to all Standard and Ingress participants having left
SIP callee did not respond in time
UserRejected = 12
SIP callee rejected the call (busy)
SipTrunkFailure = 13
SIP protocol failure or unexpected response
ConnectionTimeout = 14
server timed out a participant session
MediaFailure = 15
media stream failure or media timeout
AgentError = 16
agent encountered an error
Implementations
Sourceimpl DisconnectReason
impl DisconnectReason
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.