AnalyticsEvent

Struct AnalyticsEvent 

pub struct AnalyticsEvent {
Show 34 fields pub id: String, pub type: i32, pub timestamp: Option<Timestamp>, pub room_id: String, pub room: Option<Room>, pub participant_id: String, pub participant: Option<ParticipantInfo>, pub track_id: String, pub track: Option<TrackInfo>, pub analytics_key: String, pub client_info: Option<ClientInfo>, pub client_meta: Option<AnalyticsClientMeta>, pub egress_id: String, pub ingress_id: String, pub max_subscribed_video_quality: i32, pub publisher: Option<ParticipantInfo>, pub mime: String, pub egress: Option<EgressInfo>, pub ingress: Option<IngressInfo>, pub error: String, pub rtp_stats: Option<RtpStats>, pub video_layer: i32, pub node_id: String, pub sip_call_id: String, pub sip_call: Option<SipCallInfo>, pub sip_trunk_id: String, pub sip_inbound_trunk: Option<SipInboundTrunkInfo>, pub sip_outbound_trunk: Option<SipOutboundTrunkInfo>, pub sip_dispatch_rule_id: String, pub sip_dispatch_rule: Option<SipDispatchRuleInfo>, pub sip_transfer: Option<SipTransferInfo>, pub report: Option<ReportInfo>, pub api_call: Option<ApiCallInfo>, pub webhook: Option<WebhookInfo>,
}

Fields

id: String

unique id for this event

type: i32timestamp: Option<Timestamp>room_id: Stringroom: Option<Room>participant_id: Stringparticipant: Option<ParticipantInfo>track_id: Stringtrack: Option<TrackInfo>analytics_key: Stringclient_info: Option<ClientInfo>client_meta: Option<AnalyticsClientMeta>egress_id: Stringingress_id: Stringmax_subscribed_video_quality: i32publisher: Option<ParticipantInfo>mime: Stringegress: Option<EgressInfo>ingress: Option<IngressInfo>error: Stringrtp_stats: Option<RtpStats>video_layer: i32node_id: Stringsip_call_id: Stringsip_call: Option<SipCallInfo>sip_trunk_id: Stringsip_inbound_trunk: Option<SipInboundTrunkInfo>sip_outbound_trunk: Option<SipOutboundTrunkInfo>sip_dispatch_rule_id: Stringsip_dispatch_rule: Option<SipDispatchRuleInfo>sip_transfer: Option<SipTransferInfo>report: Option<ReportInfo>api_call: Option<ApiCallInfo>webhook: Option<WebhookInfo>

Implementations

Source

impl AnalyticsEvent

pub fn type(&self) -> AnalyticsEventType

Returns the enum value of type, or the default if the field is set to an invalid enum value.

pub fn set_type(&mut self, value: AnalyticsEventType)

Sets type to the provided enum value.

pub fn max_subscribed_video_quality(&self) -> VideoQuality

Returns the enum value of max_subscribed_video_quality, or the default if the field is set to an invalid enum value.

pub fn set_max_subscribed_video_quality(&mut self, value: VideoQuality)

Sets max_subscribed_video_quality to the provided enum value.