pub struct AnalyticsRoom {
pub id: String,
pub name: String,
pub project_id: String,
pub created_at: Option<Timestamp>,
pub participants: Vec<AnalyticsRoomParticipant>,
}Fields
id: Stringname: Stringproject_id: Stringcreated_at: Option<Timestamp>participants: Vec<AnalyticsRoomParticipant>Trait Implementations
Sourceimpl Clone for AnalyticsRoom
impl Clone for AnalyticsRoom
Sourcefn clone(&self) -> AnalyticsRoom
fn clone(&self) -> AnalyticsRoom
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnalyticsRoom
impl Debug for AnalyticsRoom
Sourceimpl Default for AnalyticsRoom
impl Default for AnalyticsRoom
impl<'de> Deserialize<'de> for AnalyticsRoom
impl<'de> Deserialize<'de> for AnalyticsRoom
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for AnalyticsRoom
impl Message for AnalyticsRoom
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AnalyticsRoom
impl PartialEq for AnalyticsRoom
Sourcefn eq(&self, other: &AnalyticsRoom) -> bool
fn eq(&self, other: &AnalyticsRoom) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for AnalyticsRoom
impl Serialize for AnalyticsRoom
impl StructuralPartialEq for AnalyticsRoom