pub struct AnalyticsStat {Show 14 fields
pub id: String,
pub analytics_key: String,
pub kind: i32,
pub time_stamp: Option<Timestamp>,
pub node: String,
pub room_id: String,
pub room_name: String,
pub participant_id: String,
pub track_id: String,
pub score: f32,
pub streams: Vec<AnalyticsStream>,
pub mime: String,
pub min_score: f32,
pub median_score: f32,
}Fields
id: Stringunique id for this stat
analytics_key: Stringkind: i32time_stamp: Option<Timestamp>node: Stringroom_id: Stringroom_name: Stringparticipant_id: Stringtrack_id: Stringscore: f32average score
streams: Vec<AnalyticsStream>mime: Stringmin_score: f32median_score: f32Implementations
Sourceimpl AnalyticsStat
impl AnalyticsStat
Sourcepub fn kind(&self) -> StreamType
pub fn kind(&self) -> StreamType
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: StreamType)
pub fn set_kind(&mut self, value: StreamType)
Sets kind to the provided enum value.