pub struct AnalyticsStream {Show 18 fields
pub ssrc: u32,
pub primary_packets: u32,
pub primary_bytes: u64,
pub retransmit_packets: u32,
pub retransmit_bytes: u64,
pub padding_packets: u32,
pub padding_bytes: u64,
pub packets_lost: u32,
pub frames: u32,
pub rtt: u32,
pub jitter: u32,
pub nacks: u32,
pub plis: u32,
pub firs: u32,
pub video_layers: Vec<AnalyticsVideoLayer>,
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub packets_out_of_order: u32,
}Fields
ssrc: u32primary_packets: u32primary_bytes: u64retransmit_packets: u32retransmit_bytes: u64padding_packets: u32padding_bytes: u64packets_lost: u32frames: u32rtt: u32jitter: u32nacks: u32plis: u32firs: u32video_layers: Vec<AnalyticsVideoLayer>start_time: Option<Timestamp>end_time: Option<Timestamp>packets_out_of_order: u32Trait Implementations
Sourceimpl Clone for AnalyticsStream
impl Clone for AnalyticsStream
Sourcefn clone(&self) -> AnalyticsStream
fn clone(&self) -> AnalyticsStream
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnalyticsStream
impl Debug for AnalyticsStream
Sourceimpl Default for AnalyticsStream
impl Default for AnalyticsStream
impl<'de> Deserialize<'de> for AnalyticsStream
impl<'de> Deserialize<'de> for AnalyticsStream
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for AnalyticsStream
impl Message for AnalyticsStream
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AnalyticsStream
impl PartialEq for AnalyticsStream
Sourcefn eq(&self, other: &AnalyticsStream) -> bool
fn eq(&self, other: &AnalyticsStream) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for AnalyticsStream
impl Serialize for AnalyticsStream
impl StructuralPartialEq for AnalyticsStream