pub struct ApiCallInfo {Show 15 fields
pub project_id: String,
pub request: Option<ApiCallRequest>,
pub service: String,
pub method: String,
pub node_id: String,
pub status: i32,
pub twirp_error_code: String,
pub twirp_error_message: String,
pub room_name: String,
pub room_id: String,
pub participant_identity: String,
pub participant_id: String,
pub track_id: String,
pub started_at: Option<Timestamp>,
pub duration_ns: i64,
}Fields
project_id: Stringrequest: Option<ApiCallRequest>service: Stringmethod: Stringnode_id: Stringstatus: i32twirp_error_code: Stringtwirp_error_message: Stringroom_name: Stringroom_id: Stringparticipant_identity: Stringparticipant_id: Stringtrack_id: Stringstarted_at: Option<Timestamp>duration_ns: i64Trait Implementations
Sourceimpl Clone for ApiCallInfo
impl Clone for ApiCallInfo
Sourcefn clone(&self) -> ApiCallInfo
fn clone(&self) -> ApiCallInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ApiCallInfo
impl Debug for ApiCallInfo
Sourceimpl Default for ApiCallInfo
impl Default for ApiCallInfo
impl<'de> Deserialize<'de> for ApiCallInfo
impl<'de> Deserialize<'de> for ApiCallInfo
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for ApiCallInfo
impl Message for ApiCallInfo
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ApiCallInfo
impl PartialEq for ApiCallInfo
Sourcefn eq(&self, other: &ApiCallInfo) -> bool
fn eq(&self, other: &ApiCallInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for ApiCallInfo
impl Serialize for ApiCallInfo
impl StructuralPartialEq for ApiCallInfo