pub struct AudioRoute {
pub channel: i32,
pub match: Option<Match>,
}Fields
channel: i32match: Option<Match>Implementations
Sourceimpl AudioRoute
impl AudioRoute
Sourcepub fn channel(&self) -> AudioChannel
pub fn channel(&self) -> AudioChannel
Returns the enum value of channel, or the default if the field is set to an invalid enum value.
Sourcepub fn set_channel(&mut self, value: AudioChannel)
pub fn set_channel(&mut self, value: AudioChannel)
Sets channel to the provided enum value.