pub struct FeatureUsageInfo {
pub feature: i32,
pub project_id: String,
pub room_name: String,
pub room_id: String,
pub participant_identity: String,
pub participant_id: String,
pub track_id: String,
pub time_ranges: Vec<TimeRange>,
pub feature_info: HashMap<String, String>,
}Fields
feature: i32project_id: Stringroom_name: Stringroom_id: Stringparticipant_identity: Stringparticipant_id: Stringtrack_id: Stringtime_ranges: Vec<TimeRange>time ranges during which the feature was enabled. for e. g., noise cancellation may not be applied when a media track is paused/muted, this allows reporting only periods during which a feature is active.
feature_info: HashMap<String, String>Feature specific metadata included in the report
Implementations