pub struct FileOutput {
pub file_type: i32,
pub filepath: String,
pub disable_manifest: bool,
}Expand description
Unified file output — replaces v1 EncodedFileOutput and DirectFileOutput. Whether transcoded depends on encoding options on the request.
Fields
file_type: i32filepath: Stringdisable_manifest: boolImplementations
Sourceimpl FileOutput
impl FileOutput
Sourcepub fn file_type(&self) -> EncodedFileType
pub fn file_type(&self) -> EncodedFileType
Returns the enum value of file_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_file_type(&mut self, value: EncodedFileType)
pub fn set_file_type(&mut self, value: EncodedFileType)
Sets file_type to the provided enum value.