pub struct ParticipantInfo {Show 19 fields
pub sid: String,
pub identity: String,
pub state: i32,
pub tracks: Vec<TrackInfo>,
pub metadata: String,
pub joined_at: i64,
pub joined_at_ms: i64,
pub name: String,
pub version: u32,
pub permission: Option<ParticipantPermission>,
pub region: String,
pub is_publisher: bool,
pub kind: i32,
pub attributes: HashMap<String, String>,
pub disconnect_reason: i32,
pub kind_details: Vec<i32>,
pub data_tracks: Vec<DataTrackInfo>,
pub client_protocol: i32,
pub capabilities: Vec<i32>,
}Fields
sid: Stringidentity: Stringstate: i32tracks: Vec<TrackInfo>metadata: Stringjoined_at: i64timestamp when participant joined room, in seconds
joined_at_ms: i64timestamp when participant joined room, in milliseconds
name: Stringversion: u32permission: Option<ParticipantPermission>region: Stringis_publisher: boolindicates the participant has an active publisher connection and can publish to the server
kind: i32attributes: HashMap<String, String>disconnect_reason: i32kind_details: Vec<i32>data_tracks: Vec<DataTrackInfo>client_protocol: i32protocol version used for client feature compatibility
capabilities: Vec<i32>capabilities the participant’s client advertises, mirrored from ClientInfo. Lets other participants perform client-side feature detection.
Implementations
Sourceimpl ParticipantInfo
impl ParticipantInfo
Sourcepub fn state(&self) -> State
pub fn state(&self) -> State
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn kind(&self) -> Kind
pub fn kind(&self) -> Kind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn disconnect_reason(&self) -> DisconnectReason
pub fn disconnect_reason(&self) -> DisconnectReason
Returns the enum value of disconnect_reason, or the default if the field is set to an invalid enum value.
Sourcepub fn set_disconnect_reason(&mut self, value: DisconnectReason)
pub fn set_disconnect_reason(&mut self, value: DisconnectReason)
Sets disconnect_reason to the provided enum value.
Sourcepub fn kind_details(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<KindDetail>>
pub fn kind_details( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<KindDetail>>
Returns an iterator which yields the valid enum values contained in kind_details.
Sourcepub fn push_kind_details(&mut self, value: KindDetail)
pub fn push_kind_details(&mut self, value: KindDetail)
Appends the provided enum value to kind_details.
Sourcepub fn capabilities(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Capability>>
pub fn capabilities( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Capability>>
Returns an iterator which yields the valid enum values contained in capabilities.
Sourcepub fn push_capabilities(&mut self, value: Capability)
pub fn push_capabilities(&mut self, value: Capability)
Appends the provided enum value to capabilities.