PublishDataTrackRequest

Struct PublishDataTrackRequest 

pub struct PublishDataTrackRequest {
    pub pub_handle: u32,
    pub name: String,
    pub encryption: i32,
    pub frame_encoding: Option<DataTrackFrameEncoding>,
    pub schema: Option<DataTrackSchemaId>,
}

Fields

pub_handle: u32

Client-assigned, 16-bit identifier that will be attached to packets sent by the publisher. This must be non-zero and unique for each data track published by the publisher.

name: String

Human-readable identifier (e.g., geoLocation, servoPosition.x, etc.), unique per publisher. This must be non-empty and no longer than 256 characters.

encryption: i32

Method used for end-to-end encryption (E2EE) on frame payloads.

frame_encoding: Option<DataTrackFrameEncoding>

Encoding for frame payloads on this track. If unspecified, the track is untyped.

schema: Option<DataTrackSchemaId>

ID of the schema used by frames on this track if the track is typed. If set, the associated schema must be stored with StoreDataBlobRequest.

Implementations

Source

impl PublishDataTrackRequest

pub fn encryption(&self) -> Type

Returns the enum value of encryption, or the default if the field is set to an invalid enum value.

pub fn set_encryption(&mut self, value: Type)

Sets encryption to the provided enum value.