pub struct SipMediaConfig {
pub only_listed_codecs: bool,
pub codecs: Vec<SipCodec>,
pub encryption: Option<i32>,
}Fields
only_listed_codecs: boolif set, ignore the default codecs and use the list below.
codecs: Vec<SipCodec>List of allowed codecs. If only_listed_codecs is not set, this list is added to default codecs.
encryption: Option<i32>Implementations
Sourceimpl SipMediaConfig
impl SipMediaConfig
Sourcepub fn encryption(&self) -> SipMediaEncryption
pub fn encryption(&self) -> SipMediaEncryption
Returns the enum value of encryption, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_encryption(&mut self, value: SipMediaEncryption)
pub fn set_encryption(&mut self, value: SipMediaEncryption)
Sets encryption to the provided enum value.