SipOutboundConfig

Struct SipOutboundConfig 

pub struct SipOutboundConfig {
    pub hostname: String,
    pub destination_country: String,
    pub transport: i32,
    pub auth_username: String,
    pub auth_password: String,
    pub headers_to_attributes: HashMap<String, String>,
    pub attributes_to_headers: HashMap<String, String>,
    pub from_host: String,
}

Fields

hostname: String

SIP server address

destination_country: String

country where the call terminates as ISO 3166-1 alpha-2 (https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2). This will be used by the livekit infrastructure to route calls.

transport: i32

SIP Transport used for outbound call.

auth_username: String

Username and password used to authenticate with SIP server. May be empty to have no authentication.

auth_password: Stringheaders_to_attributes: HashMap<String, String>

Map SIP X-* headers from 200 OK to SIP participant attributes. Keys are the names of X-* headers and values are the names of attributes they will be mapped to.

attributes_to_headers: HashMap<String, String>

Map LiveKit attributes to SIP X-* headers when sending BYE or REFER requests. Keys are the names of attributes and values are the names of X-* headers they will be mapped to.

from_host: String

Optional custom hostname for the ‘From’ SIP header. When set, outbound calls use this host instead of the default project SIP domain.

Implementations

Source

impl SipOutboundConfig

pub fn transport(&self) -> SipTransport

Returns the enum value of transport, or the default if the field is set to an invalid enum value.

pub fn set_transport(&mut self, value: SipTransport)

Sets transport to the provided enum value.