pub struct UpdateEgressRequest {
pub egress_id: String,
pub url: String,
pub layout: String,
pub add_stream_urls: Vec<String>,
pub remove_stream_urls: Vec<String>,
}Fields
egress_id: Stringurl: Stringlayout: Stringadd_stream_urls: Vec<String>remove_stream_urls: Vec<String>Trait Implementations
Sourceimpl Clone for UpdateEgressRequest
impl Clone for UpdateEgressRequest
Sourcefn clone(&self) -> UpdateEgressRequest
fn clone(&self) -> UpdateEgressRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateEgressRequest
impl Debug for UpdateEgressRequest
Sourceimpl Default for UpdateEgressRequest
impl Default for UpdateEgressRequest
impl<'de> Deserialize<'de> for UpdateEgressRequest
impl<'de> Deserialize<'de> for UpdateEgressRequest
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for UpdateEgressRequest
impl Message for UpdateEgressRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for UpdateEgressRequest
impl PartialEq for UpdateEgressRequest
Sourcefn eq(&self, other: &UpdateEgressRequest) -> bool
fn eq(&self, other: &UpdateEgressRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for UpdateEgressRequest
impl Serialize for UpdateEgressRequest
impl StructuralPartialEq for UpdateEgressRequest