pub struct SipOutboundTrunkInfo {Show 17 fields
pub sip_trunk_id: String,
pub name: String,
pub metadata: String,
pub address: String,
pub destination_country: String,
pub transport: i32,
pub numbers: Vec<String>,
pub auth_username: String,
pub auth_password: String,
pub headers: HashMap<String, String>,
pub headers_to_attributes: HashMap<String, String>,
pub attributes_to_headers: HashMap<String, String>,
pub include_headers: i32,
pub media_encryption: i32,
pub from_host: String,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
}Fields
sip_trunk_id: Stringname: StringHuman-readable name for the Trunk.
metadata: StringUser-defined metadata for the Trunk.
address: StringHostname or IP that SIP INVITE is sent too. Note that this is not a SIP URI and should not contain the ‘sip:’ protocol prefix.
destination_country: Stringcountry where the call terminates as ISO 3166-1 alpha-2 (https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2). This will be used by the livekit infrastructure to route calls.
transport: i32SIP Transport used for outbound call.
numbers: Vec<String>Numbers used to make the calls. Random one from this list will be selected.
auth_username: StringUsername and password used to authenticate with SIP server. May be empty to have no authentication.
auth_password: Stringheaders: HashMap<String, String>Include these SIP X-* headers in INVITE request. These headers are sent as-is and may help identify this call as coming from LiveKit for the other SIP endpoint.
headers_to_attributes: HashMap<String, String>Map SIP X-* headers from 200 OK to SIP participant attributes. Keys are the names of X-* headers and values are the names of attributes they will be mapped to.
attributes_to_headers: HashMap<String, String>Map LiveKit attributes to SIP X-* headers when sending BYE or REFER requests. Keys are the names of attributes and values are the names of X-* headers they will be mapped to.
include_headers: i32Map SIP headers from 200 OK to sip.h.* participant attributes automatically.
When the names of required headers is known, using headers_to_attributes is strongly recommended.
When mapping 200 OK headers to follow-up request headers with attributes_to_headers map, lowercase header names should be used, for example: sip.h.x-custom-header.
media_encryption: i32from_host: StringOptional custom hostname for the ‘From’ SIP header in outbound INVITEs. When set, outbound calls from this trunk will use this host instead of the default project SIP domain. Enables originating calls from custom domains.
created_at: Option<Timestamp>updated_at: Option<Timestamp>Implementations
Sourceimpl SipOutboundTrunkInfo
impl SipOutboundTrunkInfo
Sourcepub fn transport(&self) -> SipTransport
pub fn transport(&self) -> SipTransport
Returns the enum value of transport, or the default if the field is set to an invalid enum value.
Sourcepub fn set_transport(&mut self, value: SipTransport)
pub fn set_transport(&mut self, value: SipTransport)
Sets transport to the provided enum value.
Sourcepub fn include_headers(&self) -> SipHeaderOptions
pub fn include_headers(&self) -> SipHeaderOptions
Returns the enum value of include_headers, or the default if the field is set to an invalid enum value.
Sourcepub fn set_include_headers(&mut self, value: SipHeaderOptions)
pub fn set_include_headers(&mut self, value: SipHeaderOptions)
Sets include_headers to the provided enum value.
Sourcepub fn media_encryption(&self) -> SipMediaEncryption
pub fn media_encryption(&self) -> SipMediaEncryption
Returns the enum value of media_encryption, or the default if the field is set to an invalid enum value.
Sourcepub fn set_media_encryption(&mut self, value: SipMediaEncryption)
pub fn set_media_encryption(&mut self, value: SipMediaEncryption)
Sets media_encryption to the provided enum value.